#
# spec file for package libdxfrw
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Asterios Dramis <asterios.dramis@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 1

Name:           libdxfrw
Version:        2.2.0+git.20221210
Release:        1.5
Summary:        Library to read and write DXF files
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/LibreCAD/libdxfrw/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  ninja

%description
libdxfrw is a free C++ library to read and write DXF files in both formats,
ascii and binary form.

%package devel
Summary:        Development files for libdxfrw
Group:          Development/Libraries/C and C++
Requires:       libdxfrw%{so_ver} = %{version}

%description devel
This package includes development files for libdxfrw.

%package tools
Summary:        Tools based on libdxfrw
Group:          Productivity/Graphics/CAD

%description tools
This package includes tools based on libdxfrw.

%package -n libdxfrw%{so_ver}
Summary:        Library to read and write DXF files
Group:          System/Libraries

%description -n libdxfrw%{so_ver}
libdxfrw is a free C++ library to read and write DXF files in both formats,
ascii and binary form.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake
%cmake_build

%install
%cmake_install

%post -n libdxfrw%{so_ver} -p /sbin/ldconfig

%postun -n libdxfrw%{so_ver} -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog README TODO
%license COPYING
%{_includedir}/libdxfrw/
%{_libdir}/pkgconfig/libdxfrw.pc
%dir %{_libdir}/cmake/libdxfrw/
%{_libdir}/cmake/libdxfrw/*.cmake
%{_libdir}/libdxfrw.so

%files tools
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog README TODO
%license COPYING
%{_bindir}/dwg2dxf
%{_mandir}/man1/dwg2dxf.1.gz

%files -n libdxfrw%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libdxfrw.so.%{so_ver}*

%changelog
* Fri Jun 23 2023 jslaby@suse.cz
- Update to version 2.2.0+git.20221210:
  * fix: DWG reading failed always after 1st error
  * Do not treat warnings as errors on MSVC
  * fixed #64, DRW_Solid::fourthCorner() returns wrong coord
  * fixed #71, erroneous upper/lower string comparison
  * README.md : Improve formatting
  * CMake building of doc and dwg2dxf optional
  * add FUNDING.yml for sponsors [ci skip]
* Mon Sep 19 2022 jslaby@suse.cz
- Update to version 1.1.0~rc1+git.20220905:
  * inconsistent $MEASUREMENT/$INSUNITS variables, fixes LibreCAD/LibreCAD#636
* Tue Jul 26 2022 jslaby@suse.cz
- Update to version 1.1.0~rc1+git.20220702:
  * removed unnecessary std::endl calls which were causing significant slowdown when writing to file
  * fix "iterator after end" error on some strings
  * minor, removed superfluous semicolon
  * fix processViewport(), removed misplaced break
- switch to obs_scm
* Tue Jan 18 2022 jslaby@suse.cz
- Update to version 1.0.1+git.20220109:
  * fixed ambiguous error for DRW_Dimension::parseDwg()
  * fixed enless while()-loop for pre 2004 versions
  * dwgReader::readDwgObjects() stop reading after 1st error
  * dwgReader::readDwgEntities() stop reading after 1st error
  * replace ENTRY_PARSE macro with template method
  * remove unused DRW_Class::parseCode() method
  * protect vector<>.reserve() calls
  * Added NULL check for hatch code 93
  * Fix bounds check in DRW_LWPolyline
  * fix, check maxClassNum for valid value
  * fixed wrong 2010+ check for 64-bit size
  * Set compiler warnings on by default, because makes harder for bugs to go undetected. 	modified:   CMakeLists.txt
  * Fixed fall through and other warnings (#54)
  * fix "Vertex ID" printout
- remove (it is upstream)
  * 0001-fix-Vertex-ID-printout.patch
* Mon Dec 20 2021 jslaby@suse.cz
- Update to version 1.0.1+git.20211110:
  * fixed heap use after free vulnerability CVE-2021-21900 (bsc#1192938)
  * minor improvements to dwg2dxf, formatting and message output on success
  * fixed heap buffer overflow vulnerability CVE-2021-21899 (bsc#1192937)
  * dwg2dxf - enable debug output of libdxfrw by command line switch
  * fixed out-of-bounds write vulnerability CVE-2021-21898 (bsc#1192936)
  * fixed please note section formatting
  * updated README.md for LibreCAD_3 branch and sf.net successor
  * fixed LibreCAD 2 issue #1371, read failed with binary DXF
  * Use ununordered_map instead of map
  * manual merge changes from LibreCAD2
  * and much more
- added
  * 0001-fix-Vertex-ID-printout.patch
- removed (they are upstream)
  * drw_header-fix-indentation-level.patch
  * libdxfrw.pc.in-fix-expansion-and-include-path.patch
* Tue May  4 2021 jslaby@suse.cz
- Update to version 1.0.1+git.20200429:
  * Fix includes install dir
  * Export target as libdxfrw::libdxfrw to keep consistency with Conan packages
  * Add archive destination in install
  * Install DXFRW::dxfrw target
  * Remove duplicate target properties
  * Remove version from pkg-config file
  * Let CMake handle C++11 compiler definition
  * Change minimal required CMake version to 3.0
  * cmake: add doc target
  * README.md: fix typo
  * cmake: generate and install pkgconfig
  * cmake: add one for dwg2dxf
  * cmake: set library VERSIONs
  * cmake: use GNUInstallDirs
- add patches (build fixes)
  * libdxfrw.pc.in-fix-expansion-and-include-path.patch
  * drw_header-fix-indentation-level.patch
- remove patches (they got upstreamed)
  * 0001-cmake-use-GNUInstallDirs.patch
  * 0002-cmake-set-library-VERSIONs.patch
  * 0003-cmake-add-one-for-dwg2dxf.patch
  * 0004-cmake-generate-and-install-pkgconfig.patch
* Sun May 19 2019 jslaby@suse.com
- switch from sourceforge to more up-to-date github repo
- Update to version 0.6.3+git.20190501:
  * Add build status and update example link
  * Add Travis-CI script
  * [#10] Fix compilation on GCC
  * Fix bugs with .dwg import of TEXT and MTEXT entities
  * This was unnecessary
  * Link libdxfrw against libstdc++
  * Return an error when the file ends prematurely
  * Add version getter
  * Fix polyline 2d/3d write
  * Initialize return buffers in GetRawChar8 et al.
- add
  * 0001-cmake-use-GNUInstallDirs.patch
  * 0002-cmake-set-library-VERSIONs.patch
  * 0003-cmake-add-one-for-dwg2dxf.patch
  * 0004-cmake-generate-and-install-pkgconfig.patch
- remove
  * libdxfrw-LibreCad-2.1.0-changes.patch
* Tue Jun  7 2016 jslaby@suse.com
- add libdxfrw-LibreCad-2.1.0-changes.patch
- we need -std=c++11 for that patch to work
* Tue Dec  8 2015 p.drouand@gmail.com
- Update to version 0.6.3
  * No changelog available for this version
* Wed Sep  9 2015 asterios.dramis@gmail.com
- Update to version 0.6.1:
  * Detailed changelog not available.
  From version 0.6.0:
  * First version with dwg read support.
* Fri Aug  8 2014 asterios.dramis@gmail.com
- Update to version 0.5.12:
  * Detailed changelog not available.
* Fri May  9 2014 jengelh@inai.de
- Set RPM group to more usual values
* Wed Feb 19 2014 asterios.dramis@gmail.com
- Initial rpm release (version 0.5.11).
